C++ Initialization Classes
==========

.. doxygenstruct:: FROutput
   :members:

.. doxygenclass:: FacialReduction
   :members:

.. doxygenclass:: SparseCenter
   :members:

.. doxygenclass:: DenseCenter
   :members: